package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`MP`!````"")```````!``````````)"O````
M`````````$``.``)`$``'0`<``8````$````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````=`````````!T``````````0`````````!````
M!0````````````````!``````````$```````#R7````````/)<`````````
M``$```````$````&````P)T```````#`G4$``````,"=00``````8`0`````
M``"H%````````````0```````@````8```#8G0```````-B=00``````V)U!
M`````````@`````````"````````"``````````$````!````%@"````````
M6`)```````!8`D```````$0`````````1``````````$`````````%#E=&0$
M````>(\```````!XCT```````'B/0```````#`$````````,`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````,"=````````P)U!``````#`G4$`
M`````$`"````````0`(````````!`````````"]L:6(V-"]L9"UL:6YU>"UA
M87)C:#8T+G-O+C$`````!````!`````!````1TY5```````#````!P``````
M```$````%`````,```!'3E4`/C'N$U^S%T`HIO#^]TWZ.RR7S+4`````4@``
M`$$````$````"````"$<$``%P`2&*`)0!9"&08S"*0`D22`$B[BB.$6Z!`(*
M``````````!!````0P``````````````1````$4``````````````$8```!'
M````````````````````2````$D```!*``````````````!+`````````$P`
M``!.`````````%````!1`````````%(``````````````%,`````````````
M`%0``````````````%4```!6``````````````!7````6```````````````
M6@```````````````````````````````````%P```!=````7P````````!@
M``````````````!A````8@````````!C`````````&0`````````````````
M````````9@```&<`````````:````&D`````````````````````````````
M`&H```!K``````````P4XIX!KS3H0T75[+F-\0[C1\8!+\6;MONA;&`Y\HL<
MV7%8'+OCDGP5C"7,B`=PTR'_Y`Z^VE<;9Z_,9L6)!9#;S>.>5Z2;EF_%WQ^'
M^9R!"XH05[,!BV_AIP(*##J7"]5DU'RL2^/`R=6R<:?=HVM^J9R;H^#[22%B
M9`?%N9Q`P^4_+'=4/)1K&IY0ZM/O#FM_FGQ#^M>':PE#UC-BV^U[\$IKS]Y'
M+5GOEWD`````````````````````````````````````U0(``!(`````````
M````````````````[@(``!(`````````````````````````A`(``!(`````
M````````````````````L0(``!(`````````````````````````]@(``!(`
M````````````````````````6`(``!(`````````````````````````$0``
M`"``````````````````````````D@(``!(`````````````````````````
M3P(``!(`````````````````````````?0(``!(`````````````````````
M````9@(``!(`````````````````````````G`$``!(`````````````````
M````````N`(``!(`````````````````````````^@```!(`````````````
M````````````*0$``!(`````````````````````````,`(``!(`````````
M````````````````4@$``!(`````````````````````````&P(``!(`````
M````````````````````:0$``!(`````````````````````````B@```!(`
M````````````````````````(@,``!(`````````````````````````W`(`
M`!(`````````````````````````=@(``!(`````````````````````````
MJ@$``!(`````````````````````````'@$``!(`````````````````````
M````_@$``!(`````````````````````````1@$``!(`````````````````
M````````S`$``!(`````````````````````````;@(``!(`````````````
M````````````J@(``!(`````````````````````````70(``!(`````````
M````````````````$0,``!(`````````````````````````X`$``!(`````
M````````````````````Z@```!(`````````````````````````+0```"``
M````````````````````````"P,``!(`````````````````````````HP(`
M`!(`````````````````````````K@```!(`````````````````````````
M,`,``!(`````````````````````````/@(``!(`````````````````````
M````L0,``!(`````````````````````````%0(``!(`````````````````
M````````D`$``!(`````````````````````````"0$``!(`````````````
M````````````5@```!(`````````````````````````R@(``!(`````````
M````````````````+@$``!(`````````````````````````@@$``!(`````
M````````````````````10(``!(`````````````````````````80```!(`
M````````````````````````WP```!(`````````````````````````O0``
M`!(`````````````````````````*0(``!(`````````````````````````
M?````!(`````````````````````````!@(``!(`````````````````````
M````BP(``!(`````````````````````````Y@$``!(`````````````````
M````````;0```!(`````````````````````````I0```!(`````````````
M````````````G`(``!(`````````````````````````/````"``````````
M````````````````[0$``!(`````````````````````````-P(``!(`````
M````````````````````*@,``!(`````````````````````````<`,``!(`
M#0!X44````````0`````````S@,``!``&0!HLD$`````````````````Q@,`
M`!``&``@HD$`````````````````O@0``!(`"P"P&T``````````````````
MV0,``!(`#0!8+4```````"P`````````@`,``!(`#0!8*T````````0`````
M````FP0``!(`#0`8,4```````.P`````````!`,``!$`&0`@HD$```````@`
M````````>@0``!``&0`@HD$`````````````````5@0``!``&0!HLD$`````
M````````````NP0``!(`#0#034```````%0`````````3`0``!$`&``8HD$`
M``````@`````````C@0``!(`#0!@*T```````/0!````````S0,``!``&0!H
MLD$`````````````````Y@,``!(`#0"(+4```````!P!````````/P,``"$`
M&0`XHD$```````@`````````/`0``!(`#0#X4$```````'P`````````=P$`
M`!$`&0`HHD$```````0`````````N@,``!(`#0"`/$```````(``````````
MS@```!(```!@'T``````````````````F````!$`&0`PHD$```````$`````
M````K00``!(`#0!P,$```````(0`````````)@0``!(`#0"(*D```````-``
M````````#`0``"``&``(HD$`````````````````Q`0``!(`#0"8.$``````
M`.0#````````%P0``!$`#P"044````````0`````````,P$``!(```#0'D``
M````````````````0`,``"$`&0`XHD$```````@`````````GP,``!(`#0#X
M,$```````"``````````8P0``!(`#0"H+D```````,@!````````7@,``!$`
M%`#0G4$```````@`````````/@,``!$`&0`XHD$```````@`````````A@0`
M`!(`#0``*D```````#0`````````D0,``!``&0`@HD$`````````````````
M<`0``!(`#0!03T```````)0!````````>@,``!(`#@!\44``````````````
M````Z0(``!(`#0``($````````@"````````_P,``!(`#0`H3D```````"@!
M````````"@0``!``&``(HD$`````````````````$`0``!(`#0`((D``````
M````````````60$``!(```"@'$``````````````````\@,``!(`#0`(,D``
M`````(P&````````6P0``!``&0!HLD$``````````````````&QI8G!E<FPM
M-2XR."YS;P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T
M87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7VYE=UA3`%!E
M<FQ?;6=?<V5T`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?879?9F5T8V@`4&5R;%]S
M=E]S971P=@!03%]D;U]U;F1U;7``<&5R;%]R=6X`4&5R;%]S>7-?:6YI=#,`
M4&5R;%]N97=84U]F;&%G<P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?<&%R<V4`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`'!E<FQ?86QL;V,`<&5R;%]F<F5E`%!E<FQ?871F;W)K7W5N;&]C
M:P!097)L7W-A9F5S>7-M86QL;V,`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?9&5S
M=')U8W0`4$Q?=&AR7VME>0!097)L7W-Y<U]T97)M`%!E<FQ?9V5T7W-V`%!E
M<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`;&EB<'1H<F5A9"YS;RXP
M`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C
M871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!R;61I<@!?7W-T<FYC<'E?
M8VAK`'-T<F-H<@!G971P:60`=6YL:6YK`'-T<F-M<`!R96%D9&ER-C0`<F5A
M9&QI;FL`97AI=`!C;&]S961I<@!O<&5N9&ER`')E86QL;V,`;65M<V5T`&=E
M='5I9`!S=')T;VL`;65M8VAR`%]?>'-T870V-`!S=')S='(`86-C97-S`'-T
M<F1U<`!S=')L96X`7U]R96=I<W1E<E]A=&9O<FL`7U]L>'-T870V-`!M96UC
M<'D`7U]L:6)C7W-T87)T7VUA:6X`;65M;6]V90!?7W-P<FEN=&9?8VAK`'-T
M9&5R<@!A8F]R=`!?7W-T86-K7V-H:U]F86EL`'-T<FYC;7``;6MD:7(`7U]F
M<')I;G1F7V-H:P!?7V5N=FER;VX`;&0M;&EN=7@M86%R8V@V-"YS;RXQ`%]?
M<W1A8VM?8VAK7V=U87)D`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E
M>&5C`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`
M<&%R7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B87-E;F%M90!P
M87)?9&ER;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?7V1A=&%?<W1A
M<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB
M8U]C<W5?:6YI=`!M>5]P87)?<&P`7V5N9`!?7V5N9%]?`'!A<E]I;FET7V5N
M=@!S:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`
M<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI=`!84U])
M;G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXQ-P`````"``(``@`"``(``@``
M``(``@`"``(````"```````"``(``@```````@`"``(```````,````#``(`
M`@`"``(``P```````@`"`````@`"``(``@`````````"``(````"````````
M``(````#``(``P```````@````,``@`"``$``0`!``$``0`!``$``@`!``$`
M`0`!``$``0`!``(``0````$```````$``0`!``$``0````(``0`!``0``@`!
M``$``0`!``$``0`!``$````!``$````!``$`2`,``!`````@````EY&6!@``
M!`#:!`````````$``0"\`0``$````"````"7D98&```#`-H$`````````0`!
M``L"```0`````````)>1E@8```(`V@0```````#@GT$```````$$```C````
M``````````#0G4$````````$``!?```````````````@HD$````````$``!(
M```````````````HHD$````````$``!2```````````````PHD$````````$
M``!5```````````````XHD$````````$``!@````````````````H$$`````
M``($```!```````````````(H$$```````($```"```````````````0H$$`
M``````($```#```````````````8H$$```````($```$```````````````@
MH$$```````($```%```````````````HH$$```````($```&````````````
M```PH$$```````($```(```````````````XH$$```````($```)````````
M``````!`H$$```````($```*``````````````!(H$$```````($```+````
M``````````!0H$$```````($```,``````````````!8H$$```````($``!I
M``````````````!@H$$```````($```-``````````````!HH$$```````($
M```.``````````````!PH$$```````($```/``````````````!XH$$`````
M``($```0``````````````"`H$$```````($```1``````````````"(H$$`
M``````($```2``````````````"0H$$```````($```3``````````````"8
MH$$```````($```4``````````````"@H$$```````($```5````````````
M``"HH$$```````($```6``````````````"PH$$```````($```7````````
M``````"XH$$```````($```8``````````````#`H$$```````($```9````
M``````````#(H$$```````($```:``````````````#0H$$```````($```;
M``````````````#8H$$```````($```<``````````````#@H$$```````($
M```=``````````````#HH$$```````($```>``````````````#PH$$`````
M``($```?``````````````#XH$$```````($```@````````````````H4$`
M``````($```A```````````````(H4$```````($```B```````````````0
MH4$```````($```C```````````````8H4$```````($```D````````````
M```@H4$```````($```E```````````````HH4$```````($```F````````
M```````PH4$```````($```G```````````````XH4$```````($```H````
M``````````!`H4$```````($```I``````````````!(H4$```````($```J
M``````````````!0H4$```````($```K``````````````!8H4$```````($
M```L``````````````!@H4$```````($```M``````````````!HH4$`````
M``($```N``````````````!PH4$```````($``!;``````````````!XH4$`
M``````($```O``````````````"`H4$```````($```P``````````````"(
MH4$```````($```Q``````````````"0H4$```````($```R````````````
M``"8H4$```````($```S``````````````"@H4$```````($```T````````
M``````"HH4$```````($```U``````````````"PH4$```````($```V````
M``````````"XH4$```````($``!4``````````````#`H4$```````($```W
M``````````````#(H4$```````($```X``````````````#0H4$```````($
M```Y``````````````#8H4$```````($```Z``````````````#@H4$`````
M``($```[``````````````#HH4$```````($```\``````````````#PH4$`
M``````($```^``````````````#XH4$```````($```_````````````````
MHD$```````($``!```````````````#]>[^I_0,`D:@!`)3]>\&HP`-?U@``
M`````````````/![OZG0``"0$?Y'^1#B/Y$@`A_6'R`#U1\@`]4?(`/5T```
ML!$"0/D0`@"1(`(?UM```+`1!D#Y$"(`D2`"'];0``"P$0I`^1!"`)$@`A_6
MT```L!$.0/D08@"1(`(?UM```+`1$D#Y$((`D2`"'];0``"P$19`^1"B`)$@
M`A_6T```L!$:0/D0P@"1(`(?UM```+`1'D#Y$.(`D2`"'];0``"P$2)`^1`"
M`9$@`A_6T```L!$F0/D0(@&1(`(?UM```+`1*D#Y$$(!D2`"'];0``"P$2Y`
M^1!B`9$@`A_6T```L!$R0/D0@@&1(`(?UM```+`1-D#Y$*(!D2`"'];0``"P
M$3I`^1#"`9$@`A_6T```L!$^0/D0X@&1(`(?UM```+`10D#Y$`("D2`"'];0
M``"P$49`^1`B`I$@`A_6T```L!%*0/D00@*1(`(?UM```+`13D#Y$&("D2`"
M'];0``"P$5)`^1""`I$@`A_6T```L!%60/D0H@*1(`(?UM```+`16D#Y$,("
MD2`"'];0``"P$5Y`^1#B`I$@`A_6T```L!%B0/D0`@.1(`(?UM```+`19D#Y
M$"(#D2`"'];0``"P$6I`^1!"`Y$@`A_6T```L!%N0/D08@.1(`(?UM```+`1
M<D#Y$((#D2`"'];0``"P$79`^1"B`Y$@`A_6T```L!%Z0/D0P@.1(`(?UM``
M`+`1?D#Y$.(#D2`"'];0``"P$8)`^1`"!)$@`A_6T```L!&&0/D0(@21(`(?
MUM```+`1BD#Y$$($D2`"'];0``"P$8Y`^1!B!)$@`A_6T```L!&20/D0@@21
M(`(?UM```+`1ED#Y$*($D2`"'];0``"P$9I`^1#"!)$@`A_6T```L!&>0/D0
MX@21(`(?UM```+`1HD#Y$`(%D2`"'];0``"P$:9`^1`B!9$@`A_6T```L!&J
M0/D00@61(`(?UM```+`1KD#Y$&(%D2`"'];0``"P$;)`^1""!9$@`A_6T```
ML!&V0/D0H@61(`(?UM```+`1ND#Y$,(%D2`"'];0``"P$;Y`^1#B!9$@`A_6
MT```L!'"0/D0`@:1(`(?UM```+`1QD#Y$"(&D2`"'];0``"P$<I`^1!"!I$@
M`A_6T```L!'.0/D08@:1(`(?UM```+`1TD#Y$((&D2`"'];0``"P$=9`^1"B
M!I$@`A_6T```L!':0/D0P@:1(`(?UM```+`1WD#Y$.(&D2`"'];0``"P$>)`
M^1`"!Y$@`A_6T```L!'F0/D0(@>1(`(?UM```+`1ZD#Y$$('D2`"'];0``"P
M$>Y`^1!B!Y$@`A_6T```L!'R0/D0@@>1(`(?UM```+`1]D#Y$*('D2`"'];0
M``"P$?I`^1#"!Y$@`A_6T```L!'^0/D0X@>1(`(?UM```+`1`D'Y$`((D2`"
M'];]>[JI_0,`D?-3`:FT``#PE$(WD8,"0/GC+P#Y`P"`TO43`/GBAP.IXN,`
MD>$#`9'@3P"YX#,!D8+__Y?B___P0D`[D>$#`JK@___P`(`]D28,`)3```"0
M`,!(.:`)`#33``"0<R()D=4``)"@*D*Y3/__E^(#`*J@*D*Y06A2.2$`'S)!
M:!(Y1O__EP)H4CGA3T"Y0@``,@)H$CDA%``1('Q]DSO__Y?D`P"JY2-`^<``
M`)`"``#P0B`7D0,,0?D!``#PI@!`^8``@%(A0!>1A@@`J>)/0+E@!@"YY@"`
MDF0&`/E?!`!Q@P0!J2``@-(M`0!4'R`#U0$0`!&C>&#XP<PABP`$`)%?``!K
M@V@A^$S__U1%$``1XP,$JF`.0/F%S"6+0@P`$0$``)`$`(#2(>`HD;^`'_AZ
M__^7]0,`*N`#`#1@#D#Y\O[_EP```/#A4P&1`.`,D6X``)2``P"T8`Y`^=O^
M_Y=B__^7X`,5*N(O0/F!`D#Y00`!R@$$`+7S4T&I]1-`^?U[QJC``U_6TP``
MD',B"9'V_O^78`X`^0`#`+35``"0QO[_EZ`J0KG\_O^7'\0H.:W__Q=@#D#Y
M?/__E_4#`"K?__\78`I`^6```+2K!@"4XO__%^%3`9$```#P```+D4H``)1@
M"@#Y@/O_M*,&`)3:__\7^?[_ER``@%*/_O^7'0"`TAX`@-+E`P"JX0-`^>(C
M`)'F`P"1``#@T@``P/(`"*#R``"$\@,`X-(#`,#R`PB@\@,?BO($`.#2!`#`
M\@0(H/($+XKRO/[_E_/^_Y>@``#P`/!'^4```+3K_O\7P`-?UA\@`]7```"0
M`(`(D<$``)`A@`B1/P``ZZ```%0!``#P(=!`^4$``+0@`!_6P`-?UA\@`]7`
M``"0`(`(D<$``)`A@`B1(0``RR'\0Y,A_$&+(?Q!DZ$``+0"``#P0M1`^4(`
M`+1``!_6P`-?UOU[OJG]`P"1\PL`^=,``)!@`DDY@```->#__Y<@`(!28`()
M.?,+0/G]>\*HP`-?UN;__Q<?(`/5_7N\J?T#`)'S4P&I8`8`M,(``)#W8P.I
M6!Q!^3@&`+3U6P*I%0"`4@(`0#E?]`!Q1!A`>N$"`%03`T#Y\P$`M/<#`:KV
M`P"JM7Y`D_0#&*KB`Q6JX0,6JN`#$ZIQ_O^7@```-6!J=3@?]`!Q``(`5)..
M0/CS_O^U]5M"J?=C0ZG@`Q.J\U-!J?U[Q*C``U_6]0,`JJ(>0#A?]`!Q1!A`
M>J'__U2U`@!+Y/__%X`"&,NU!@"1<P(5BP#\0Y/@`@"YX`,3JO-30:GU6T*I
M]V-#J?U[Q*C``U_6$P"`TNG__Q<3`(#2]V-#J>;__Q<?(`/5_7N\J?T#`)'U
M$P#YM0``\+5"-Y'S4P&I\P,`JJ`"0/G@'P#Y``"`TM0``)#ATP"1X`,3JK?_
M_Y<``@"T@AY!^>,W@+E`#`.+`01`^4%X(_CA_O^T'R`#U0`@`)$!!$#Y`0``
M^:'__[7ATP"1X`,3JJC__Y=`_O^UX1]`^:`"0/D@``#*H```M?-30:GU$T#Y
M_7O$J,`#7]92_O^7'R`#U?U[N:G]`P"1\U,!J;0``/"40C>1]5L"J?,#`*J`
M`D#YX#<`^0``@-+W8P.I^6L$J2``0#D?]`!Q-12!FN`#%:K0_?^7]@,`JN&3
M`9'@`Q.JB/__EP`(`+3W`P"JR?W_EQ\`%NO"!@!4^&>`N=D``)`8\WW38`)`
M.1_T`'$$&$!ZX`L`5.$#$ZH@'$`X'_0`<0080'JA__]4(0`3RR%\0),W'T'Y
MP`H`D0```8OI_?^7X&HX^``+`+0B'T'YX`,3JN-G@+D!%$`X0GAC^#_T`'$D
M&$!Z00``.>```%0?(`/5`11`.$$<`#@_]`!Q)!A`>H'__U2A!X!2``"`TD$4
M`#BA:F`X06@@.``$`)&A__\U``"`4N(W0/F!`D#Y00`!RN$'`+7S4T&I]5M"
MJ?=C0ZGY:T2I_7O'J,`#7]8``(#2H6I@..%J(#@`!`"1H?__-?#__Q?9``"0
M^RL`^3@?0?D``T#Y``4`M.$#&*H``(!2`@``%.`#%RHBC$#X%P0`$:+__[4`
M#``1`'Q]D\$``)`B2$*Y(@(`-2(`@%(B2`*YK/W_E_L#`*I``P"T^GY`D^$#
M&*I8\WW3X@,8JFG]_Y<['P'Y6@<`D7][.OCW9P"Y^RM`^:C__Q?A`P"JX`,8
MJLS]_Y<@'P'Y^P,`JB`!`+3Z?D"36/-]T_/__Q<!`(#2J/__%P`"@-(7`(!2
MX/__%_LK0/D``(`2O___%_LK`/G(_?^7'R`#U?U[LJG]`P"1\U,!J;0``/"4
M0C>1@0)`^>%O`/D!`(#2P```M/=C`ZGW`P"J`0!`.2$!`#7W8T.IX6]`^8`"
M0/D@``#*0`D`M?-30:G]>\ZHP`-?UO5;`JE8_?^7]0,`JJ`'`+06``#P&```
M\-8B"9$80PF1X`,5JO#]_Y?@!0"T$TP`D>$#%JK@`Q.JP_W_ER#__S3A`QBJ
MX`,3JK_]_Y>@_O\TX`,7JODC`/DK_?^7^0,`JN`#$ZHH_?^7```9"P`(`!$`
M?$"36/W_E^4#$ZKD`Q>J`P``\&-@"9'Y`P"J`@"`DB$`@%(@_?^7XF,!D>$#
M&:H``(!2)/W_EQ\$`#&@``!4X&M`N0`,%!(?$$!Q@`(`5.`#&:H`_O^7X`,9
MJK[]_Y?@`Q6J^2-`^</]_Y>`^O^U'R`#U>`#%:IS_?^7X`,7JIW]_Y?U6T*I
M]V-#J;K__Q?U6T*I]V-#J;?__Q?@`QFJI___E^W__Q?U6P*I]V,#J?DC`/EH
M_?^7'R`#U?U[M:GA`P"J_0,`D?-3`:FS``#P<T(WD?0#`*KBHP"18`)`^>!7
M`/D``(#2D_W_E\`!`#7A.T"Y`@"44B$,%!(_$$!Q)!!">D`!`%3B5T#Y80)`
M^4$``<J!`0"U\U-!J?U[RZC``U_6``"`4OC__Q?@`Q2J00"`4ES]_Y<?``!Q
MX!>?&O+__Q=$_?^7'R`#U1`*@M+_8S#+XO^!TOU[`*G]`P"1\U,!J;,``/!S
M0C>1]5L"J?4#`*I@`D#YX"<(^0``@-(```#P`(`)D?<;`/GW`P&JX2,!D=#\
M_Y<?``!QC04`5,$``)`"!`!1-BA"N>$C`9$AR&(X(0,`->(#`#14?$"3X06`
M4N(#%*K@(P&1BOW_ER`#`+3@`Q8J#_W_E^,#%*KB(P&1X0,5JHO]_Y?A)TCY
M8`)`^2```,J@`P"U$`J"TOU[0*GS4T&I]5M"J?<;0/G_8S"+P`-?UN(#`"KA
M!8!2X",!D51\0)/B`Q2J<OW_ER#]_[7@`Q8J]_S_E^(#%ZKA`Q6JU/S_E^G_
M_Q?```"0%BA"N>`#%BKO_/^7X@,7JN$#%:K,_/^7X?__%_K\_Y<?(`/5_7N_
MJ<```)#]`P"1`"A"N>3\_Y?]>\&H`P``\.+___!CP`:10H`RD0$``/`AP`F1
M(/W_%Q\@`]7]>[ZI_0,`D?,+`/G3``"08"I"N=7\_Y?L__^78"I"N=+\_Y?S
M"T#Y!```\/U[PJB$`!>1`@``L.,#!*I"8"*1`0``\`4`@%(A0`J1*_W_%Q`*
MA-+_8S#+_7L`J?T#`)'S4P&ILP``\'-"-Y%@`D#YX"<0^0``@-+U$P#Y%0"`
MTHK\_Y?D`P`J!0``\`,``/"EH`J18\`*D2(`@M(A`(!2X.,`D57\_Y<""(+2
MX.,`D>%C(HL"`(+27/S_EZ`!^#?T`P"J``0`$0!\0)-[_/^7]0,`JN```+24
M?D"3`0B"TN(#%*KA8R&+-/S_E[]J-#C@`Q6JXB=0^6$"0/E!``'*X0``M1`*
MA-+]>T"I\U-!J?430/G_8S"+P`-?UJ/\_Y?,__\7'R`#U1`<@M+_8S#+_7L`
MJ?T#`)'W8P.IMP``\/="-Y'Y:P2I^@,`JN`"0/G@;PCY``"`T@```/````N1
M\U,!J?,#`:KA4P&1V_W_E_0#`*KA!8!2X`,:JN/\_Y<@`@"T````\.$#&JH`
M0`N1-O[_E^`#&JKB;TCYX0)`^4$``<J!"P"U$!R"TOU[0*GS4T&I]V-#J?EK
M1*G_8S"+P`-?UN`#&JKU6P*I!_S_EQ4``/"U@@N1^`,`*N$#%:K@`Q.J_?O_
ME_,#`*J`!@"T&0``\!8``/`Y(PF1UJ(+D6$"0#D!!@`TM```M.$#$ZK@`Q2J
MA?S_EX`$`#3@`Q.J\OO_EV+"((OA`P`J0/!?.!^\`''A``!4(00`46+"(8M_
MRB$X0O!?.%^\`'%@__]4`@<`$4$``0L__#]Q#`,`5.0#$ZH#``#PY@,:JF/`
M"Y'E`Q:J`@""TB$`@%+@8P.1WOO_E^)C`9'A8P.1``"`4N+[_Y>@```UX6M`
MN2$,%!(_($!Q``(`5.$#%:H``(#2ROO_E_,#`*I`^O^U]5M"J;'__Q>T``"T
MX0,9JN`#%*I6_/^7H/[_-/,#&:HA`(!2W/__%R$`@%+@8P.10_S_E\#]_S7A
M8P.1````\`!`"Y':_?^7X&,#D2#\_Y?U6T*IHO__%_5;`JDD_/^7'R`#U0$`
M0#GB`P"JX0``-!\@`]4`!`"1/[P`<4(0@)H!`$`Y@?__->`#`JK``U_6'R`#
MU8`(`+3]>[ZI_0,`D?,+`/GS`P"J`0!`.2$'`#2?^_^7``0`T6("`(M_`@+K
M(@,`5&!J8#@?O`!QH```5!(``!1``$`Y'[P`<>$!`%1"!`#1?P("ZV'__U1`
M`$`Y'[P`<>`$`%3S"T#Y````\/U[PJ@`H`N1\?O_%T``0#D?O`!QH`$`5$($
M`-%_`@+K8___5'\"`NL@_O]40@0`T7\"`NL"`0!4'R`#U4``0#D?O`!Q@0``
M5$($`-%_`@+K8___5$(`$\L``(#200@`D3\$0/$(`0!4P```D`2@"9%"!`"1
MX0,3JN`#!*H#`(+2H_O_E_,+0/G]>\*HP`-?UO,+0/D```#P_7O"J``@"9'+
M^_\7````\``@"9'(^_\7'R`#U0$``/`AP`:1_7NXJ2)``)$```#P_0,`D?-3
M`:FS``#P<T(WD28<0:EA`D#YX3\`^0$`@-)$%$&I`.`+D4%`0'D4``#P]5L"
MJ92B#)$5``#P]QL`^;4""Y'F'P6I%P``\/<B#9'D%P:I%@``\-9B#9'AXP!Y
M.?W_EP```/``(`R1-OW_EP```/``0`R1,_W_EP```/``@`R1,/W_E^`#%*HN
M_?^7````\`#@#)$K_?^7X`,5JBG]_Y?@`Q>J)_W_E^`#%JHE_?^7````\`"@
M#9$B_?^7````\`!`"Y$?_?^7````\.$S`9$`X`V1W_S_EX```+3A`P"JX`,6
MJC_]_Y<```#PX3,!D0!`#I'7_/^7H```M.$#`*H```#P`*`.D3;]_Y<```#P
MX3,!D0#@#I'._/^7(`(`M.$#`*K@`Q6J+OW_E^`#%*H!``#P(<`/D2K]_Y?A
M/T#Y8`)`^2```,H@`P"U\U-!J?5;0JGW&T#Y_7O(J,`#7]8```#0X3,!D0`@
M#Y&Y_/^7H```M.$#`*K@`Q>J&?W_E^O__Q<!``#0X(<!D2&`#Y%"`8#2-_O_
MEZ#\_S7AKP&1X`,7J@_]_Y?A__\77?O_E_U[O:G]`P"1\U,!J;,``-"T``#P
M<T(WD6`"0/G@%P#Y``"`TH`20KD?!``Q``$`5.(70/EA`D#Y00`!RB$"`+7S
M4T&I_7O#J,`#7];ADP"1````T``@#9&2_/^7X0,`J@``@%*A``"T(`!`.1_`
M`'$$&$!ZX`>?&H`2`KGM__\7//O_EQ\@`]7]>[^I_0,`D=SZ_Y=;^_^70```
MM```0/G]>\&HP`-?UOU[NZG]`P"1\U,!J;,``-!S0C>1%```T)3B#Y'U6P*I
M]@,`JF`"0/G@)P#Y``"`TN`#%*KA$P&1</S_EX```+0!`$`Y]0,`JH$!`#7A
M`Q:JX`,4JLW\_Y?A)T#Y8`)`^2```,H`!`"U\U-!J?5;0JG]>\6HP`-?UN$#
M%JJ+^_^7P/[_M>`#%JKW&P#YG_K_E_<#`*K@`Q6JG/K_E^`"`(L`"`"1S?K_
ME^8#%:KD`Q:J!0``T`,``-"E@`N18\`+D0(`@)+W`P"J(0"`4I/Z_Y?A`Q>J
MX`,4JJS\_Y?W&T#YWO__%_<;`/GX^O^7'R`#U1`VD-+_8S#+`@``T$+`!I']
M>P&I_4,`D4JL0ZGJ+PBI2"1%J?-3`JE&'$:I]5L#J;4``-!$%$>IM4(WD4HL
M2*GW8P2I]P,`JD,D0/G@(T"10DA`^:$"0/D!U`#Y`0"`TA8``-#6`@N1X`,6
MJN'S`9'C2P#YZJ\)J>)7`/GH)PNIYA\,J>07#:D@_/^7@```M`$`0#GS`P"J
M`2$`-?EK!:G[,P#YD___E_0#`*H`'`"TX`,4JEGZ_Y<`^'_3``0`D8KZ_Y>$
M`D`Y^P,`JJ0!`#08``#0\P,;JAA#$)$?(`/5X`,3JN,#&*H"`("2(0"`4D[Z
M_Y=S"@"1A!Y`."3__S7@6T#YX`D`M/3#`I$#```4@(Y`^&`)`+3A\P&1^_O_
ME_,#`*I@__^T`0!`.2'__S1$_?^7X/[_-.`#$ZJ?^O^7\P,`JN`'`+3@`Q.J
M,_K_E_0#`*K@`QNJ,/K_EQ0`%`N4$A`1&@``T%JC"Y&4?D"3X`,4JEWZ_Y?G
M`QNJY`,3JN4#&JH&``#0`P``T,9@$)%C@!"1`@"`DOD#`*HA`(!2(OK_E^`#
M&:H!.(!2#_O_EQ\$`#&A``!4!/O_EP4`0+F_1`!Q(18`5.*#`Y'A`QFJ``"`
M4KGZ_Y?S`P`J8`4`-*```/#D`QFJXP)`^0(``-``$$'Y0L`1D2$`@%(4`(#2
MDOK_E_EK1:G[,T#YX2-`D>`#%*HBU$#YH0)`^4$``<H!(P"U$#:0TOU[0:GS
M4T*I]5M#J?=C1*G_8S"+P`-?UO@#`I$4`(!2$]MT^+,!`+1@`D`Y8`$`-)0&
M`!'@`Q.J^/S_ER#__S3@`Q.J4_K_E_,#`*J@]O^U$]MT^+/^_[43`(#2L?__
M%^#S0+D`#!02'Q!`<6'Z_U3X^T"Y\_G_EQ\#`&OA^?]4X/-`N0`@`!(?``=Q
M8?G_5.`#%*H+^O^7X?,!D?0#`*H```#0`"`3D8[[_Y?`#P"T^`)`^3?Z_Y?A
M`P"JX`,8JIS]_Y?X`P"JX`X`M.`#&*K(^?^7^P,`JA\,`''M`0!4`'Q`DP$`
M`-``$`#1(4`3D0`#`(M/^O^7``$`-7\3`'$`%0!48!,`40##((L`\%\X'[P`
M<6`4`%3*_O^7P```->`#&*H!`(!2COK_E_<#`"K@"P`U`0``T"'`#Y$```#0
M`"`-D<O[_Y<7``#0V?G_E_<"%Y'F`P`JYP,7J@,``-#E`QJJ8\`3D>0#&:H"
M`("2(0"`4N`#%*H8``#0H?G_EQ@#%)$1```4AOK_EP``0+D?1`!Q00(`5,;Y
M_Y?W`P#Y<P8`$>8#`"KG`Q,JY0,:JN0#&:KC`QBJ`@"`DB$`@%+@`Q2JC_G_
MEP$X@%+@`Q2J?/K_EQ\$`#&`_?]4X`,9JC3Z_Y?A`Q2JX`,6JJ'[_Y?@`Q2J
MO?[_E_EK1:G[,T#Y>?__%_AC`I$3`(!2'R`#U0#;<_B``0"T<P8`$>'S`9$P
M^_^78/__M`$`0#DA__\TV/G_E_0#`*J`XO^U`-MS^,#^_[6@`8#2GOG_EQ0`
M`-#[`P"J9`J`4I0B$)$3__\7H```\.0#&:KC`D#Y`@``T``00?DA`(!20L`0
MD10`@-+H^?^7^6M%J?LS0/E6__\7EO[_E^`#$ZJ^^?^7]`,`JE'__Q?X`D#Y
MB?__%T(`@%(A`H"2I_G_E^&C!I'"`(#2X`,7*A_Z_Y?@HT8Y@```->"G1CD?
M#`%Q``@`5`(`@%(!`(#2X`,7*IKY_Y>M!0"4\P,`J@4``!3B`P`JX:,&D>`#
M$ZJ]!0"4`@"0TN&C!I'@`Q<J"_K_EQ\``''L_O]4X`,7*J?Y_Y?A`Q.J\^,%
MD1@``-![H@"1&$,0D>"#!9'W`P"J]P4`E.060#C@`Q.JXP,8J@(`@)(A`(!2
M<PH`D2CY_Y=_`Q/K`?__5.;C!9'E`QJJ!P``T`,``-#G`!>18X`3D>0#&:H"
M`("2(0"`4N`#%*K_@P8Y&OG_EY#__Q?W!D#YM^O_M.`#%ZH1^?^7'PP`\2GK
M_U0`$`#1`0``T.`"`(LA8!.1FOG_EQ\``'$8$Y>:4?__%^"K1CD?!`%QX??_
M5."O1CD?#`%Q@??_5."S1CD?(`%Q(??_5."W1CD?%`%QP?;_5$(`@%(A!X"2
MX`,7*D_Y_Y?AHP:1X`,7*B(%@-+'^?^7YJ,&D>4#&JH'``#0`P``T.<`%Y%C
M@!.1Y`,9J@(`@)(A`(!2X`,4JNSX_Y=B__\7^6L%J?LS`/E4^?^7'R`#U?U[
MN*G]`P"1]V,#J;<``/#@*D*Y^6L$J;H``-!:0S>100-`^>$_`/D!`(#2\U,!
MJ?5;`JDU^?^7\P,`JN`J0KDR^?^78>)".0'D`CD```#0X=,!D0"@#)&(^O^7
M@```M`$`0#D_Q`!QP!(`5&G]_Y?@*D*Y)?G_EP$``-!C`8!2(6`4D2(`@%(X
M^?^7X!(`M+4``/"U(@F1Z#,`_0`(0/FA!D"Y\RI"N3\$`'$(%$#]+08`5!F`
M@%+XH@B1%@"`4C0`@%(9!*!R^W,%J0H``!0A"$#YX`,<JCSY_Y>A!D"Y(`0`
M-90&`!'6!@`1/P`4:ZT#`%3@`Q,J!/G_EP$!9IX#`(!2PGY`DVSY_Y?[`P"J
MP!(`M`$`0/FB!D#Y(`Q`N1,#0+D``!D*'P`0<5S8=/@`_?]4X`,3*O3X_Y=A
M`T#Y0P"`4@(`@-+@^/^7X0,`JN`#'*H=^?^7$P-`N:$&0+D@_/\T(`0`41\`
M%FM@#`!4^W-%J>@S0/W@`Q,JX_C_EV,`@%(!``#0(@"`4B&`%)'V^/^7\P,`
MJH`!`+3@*D*YVOC_EV$*0/D"``#00J`4D2$`0/FU^/^78`I`^0``0/D`#$"Y
MP`ZP-^`J0KG/^/^7`0``T&,`@%(AP!21(@"`4N+X_Y?S`P"JH`$`M````-#A
MTP&1`$`+D2#Z_Y?T`P"JX"I"N?0+`+3`^/^780I`^>(#%*HA`$#YG/C_E^`J
M0KFZ^/^7\P,`JN`J0KFW^/^7(@"`4@$``-`AX!21[_C_EP(``-#A`P"J0D`5
MD>`#$ZJ.^/^7X"I"N:SX_Y<?Y`(YX=,!D0```-````N1`_K_EZ`*`/GS`P"J
M0`8`M`$X@%+@`Q.J-?G_EP$$`!$_!`!Q!(A1>F$)`%3A/T#Y0`-`^2```,J`
M"`"U\U-!J?5;0JGW8T.I^6M$J?U[R*C``U_6``1`.4#M_S7@*D*YC_C_EP$`
M`-!C`8!2(6`4D2(`@%*B^/^78.W_M;4``/#S*D*YM2()D:'__Q<_!`!QK?/_
M5/:B")$T`(!2`@``%-,"0+G@`Q,J??C_EP$!9IZ4!@`1-OC_EZ`&0+D?`!1K
M#/__5/,J0KG[<T6IZ#-`_8___Q>@!D#YB_W_EZ`*`/GS`P"J8/G_M0```-``
M8!61^W,%J>@S`/VI^/^7H09`N?,J0KD@!`!1'P`6:\'O_U3?__\78OC_EZ$&
M0/E@"D#Y(0!`^0``0/DK^_^7H?__%^`J0KE:^/^780I`^2$`0/FS^/^7AO__
M%_MS!:GH,P#]8_C_EZ$&0/G[<P6IXP,`*N@S`/T```#0(0!`^>(#$ZH``!:1
MBOC_EQ\@`]7]>[ZI_0,`D?-3`:GT`P"J/OS_EP$`0#GS`P"JP0``-``$`)$_
MO`!Q<Q*`F@$`0#F!__\U[_S_EY\"`/$$&$!Z@0``5/-30:G]>\*HP`-?UH`"
M0#F`__\T`0``T.`#$ZJ"`(#2(6`0D1+X_Y?`_O\UX`,4JO-30:G]>\*H<_K_
M%_^#"M&H``#0XF,`D0A!-Y$%X`"1">`!D?U[`*GD`P*J_0,`D0$!0/GA3P'Y
M`0"`TJ$`0+F$0`"1HX1`^"$(P%J!`!_XOP`)ZV'\8--G_&C3YQQXDB;<>-,A
M'`A3QAQPDN/@0ZHA``:J(0`#JH&`'_@!_O]410`(D4$`0/E"(`"10P1`^40<
M0/EC``'*03!`^2$`!,HA``/*(_Q?TV$$`:HA?$"203P`^5\`!>MA_O]4!1!`
MJ2,SC](&'$&I0U"K\NNS0:DB=)W2JOQ;TZW\0M-*%06JK7D%JN$`!LHBVZWR
M(0`$BB$`!\IK`0.+*D`JBX'\0M,A>`2J2@$+BPD00/DN?$"2RP$&RHP!`XM*
M`0D+:P$%BFL!!LHA``W*3_U;TVL!!XOO%0JJ:P$,B^L!"PM/_4+3(0`*BNIY
M"JKLOT*I(0`.RG#]6],A``:+$!8+JHP!`XOO`0.+(0`,BZP!"LH!`@$+C`$+
MBK!]0))M_4+3C`$0RJUY"ZJ,`0Z++OQ;TXP!#XM+`0W*SA4!JDI]0)+O'T#Y
MS@$,"VL!`8HL_$+3:P$*RN\!`XMK`1"+T/U;TXQY`:H0%@ZJ:P$/BZ$!#,H+
M`@L+T/U"TR$`#HH.>@ZJ[T-$J:U]0)(A``W*(0`*B^H!`XMO_5O3(0`*BXH!
M#LKO%0NJC'U`DDH!"XKO`0$+2@$,RF']0M,0`@.+*W@+JDH!#8O!`0O*2@$0
MB\Y]0)+P*T#Y[?U;TR$`#XJM%0^J(0`.RO']0M.M`0H++WH/J@H"`XLA``R+
M(0`*BVH!#\JP_5O3:WU`DDH!#8H0%@VJ2@$+RA`"`0M*`0Z+L?U"T^&[1:DM
M>@VJ#/Y;TQ'^0M.,%1"J(0`#BTH!`8OA`0W*(0`0BN]]0)(A``_*C`$*"S!Z
M$*K*`0.+(0`+BX[]6],A``J+J@$0RDH!#(JM?4"2SA4,JDH!#<K.`0$+2@$/
MB^&_1JF1_4+3+'H,JLO]6]-K%0ZJT?U"TR$``XM*`0&+`0(,RB$`#HH0?D"2
M(0`0RFL!"@LN>@ZJZ@$#BR$`#8MO_5O3(0`*BXH!#LI*`0N*C'U`DN\5"ZI*
M`0S*[P$!"TH!$(OAPT>I<?U"TRMZ"ZKM_5O3K14/JO']0M,A``.+2@$!B\$!
M"\HA``^*SGU`DB$`#LJM`0H++WH/J@H"`XLA``R+L/U;TR$`"HMJ`0_*2@$-
MBFM]0)(0%@VJ2@$+RA`"`0M*`0Z+X;M(J;']0M,M>@VJ#/Y;TXP5$*H1_D+3
M(0`#BTH!`8OA`0W*(0`0BN]]0)(A``_*C`$*"S!Z$*K*`0.+(0`+BX[]6],A
M``J+J@$0RDH!#(JM?4"2SA4,JDH!#<K.`0$+2@$/B^&_2:F1_4+3+'H,JLO]
M6]-K%0ZJ(0`#B^\!`XM*`0&+`0(,RFL!"@L0?D"2(0`.BB$`$,IJ_5O3(0`-
MB\W]0M.N>0ZJ(0`/BTH5"ZK2?4"22@$!"X$!#LHA``N*C'U`DB$`#,I1_5O3
M(0`0BS$6"JKMPTJIK0$#BP,"`XLA``V+;?U"TS%`,8NK>0NJ+WY`DL$!"\HA
M``J*[?U;TR$`$LHA``R+K14/JB$``XM#_4+3+4`MBV%X"JJP?4"2:@$!RN-?
M0/E*`1%*#OY;TTH!$HMC``*+SA40JDH!`XOL_4+33D$NBXQY#ZK1?4"2+P`,
MRNIC0/GO`0U*+?Y;T^M!*XM*`0*+K141JF,!"HL*_D+3;4`MBT-Y$*JP?4"2
MB@$#RN]G0/E*`0Y*"_Y;TTI!(8MK%1"JX0$"BTH!`8LA_D+32T$KBRIX$:IO
M?4"280`*RNYK0/DA``U*[?U;TR%`+(O.`0*+K!4/JB$`#HL-_D+3+$`LBZ%Y
M$*J0?4"23@$!RNUO0/G.`0M*"_Y;T\-!(XNM`0*+:Q40JF,`#8OM_4+3:T`K
MBZ-Y#ZIO?4"2+@`#RNUS0/G.`0Q*[/U;T\I!*HNM`0*+C!4/JDH!#8L-_D+3
M3$$LBZIY$*J0?4"2;@`*RNUW0/G.`0M*"_Y;T\%!(8NM`0*+:Q40JB$`#8OM
M_4+3*T`KBZ%Y#ZIO?4"23@$!RNU[0/G.`0Q*[/U;T\-!(XNM`0*+C!4/JF,`
M#8L-_D+3;$`LBZ-Y$*J0?4"2+@`#RNU_0/G.`0M*"_Y;T\I!*HNM`0*+:Q40
MJDH!#8OM_4+32T$KBZIY#ZIO?4"2;@`*RNV#0/G.`0Q*[/U;T\%!(8NM`0*+
MC!4/JB$`#8L-_D+3+$`LBZ%Y$*I.`0'*D'U`DLX!"TK#02.+"_Y;T^V[4*EK
M%1"JK0$"BV,`#8OM_4+3:T`KBZ-Y#ZIO?4"2+0`#RJP!#$KM_5O3BD$JBZT5
M#ZK,`0*+2@$,BPS^0M--02V+BGD0JK!]0))L``K*[H]`^8L!"TH,_EO384$A
MBXP5$*K+`0*+(0`+B^O]0M,L0"R+87D/JHM]0))/`0'*[I-`^>\!#4IM_5O3
MXT$CB\X!`HNM%0NJ8P`.BP[^0M-M0"V+PWD0JK!]0)(O``/*[I=`^>\!#$H,
M_EO3ZD$JB\X!`HN,%1"J2@$.BV[]0M-,02R+RWD+JHI]0))O``O*[IM`^>\!
M#4I-_5O3X4$AB\X!`HNM%0JJ(0`.BP[^0M,M0"V+P7D0JNZ?0/EO`0'*[P$,
M2K!]0)+.`0*+XT$CBV,`#HM._4+3RGD*J@S^6],O``K*C!40JN\!#4KK02N+
M;$`LB^X_5*F#?4"2;?Q;TZT5`ZK.`0*+[P$"BVL!#HL._D+3;4$MB\MY$*I0
M`0O*KGU`D@P"#$IP_$+3@4$AB\S]6],#>@.J(0`/BXP5#JKOJT#YC`$!"V$!
M`\HM``U*P?U"TR%X#JJJ02J+X@$"BXW]6],Q?$"2KA4,JD(!`HMM?$"2:@`!
MJLX!`@OOKT#YH@$1BDH!#(J#_4+32@$"JH*;E])BX['R8W@,JDM!*XOJ`0*+
M;'Q`DFL!"HLJ``.J(0(,BDH!#HK0_5O32@$!JA`6#JI*`0V+$`(+"^\W5JG!
M_4+3(7@.JBY\0)+K`0*+#_Y;TTH!"XOO%1"J:P`!JN\!"@N#`0Z*:P$0BFL!
M`ZH#_D+3J@$"BV-X$*IK`1&+[?U;TW!\0))K`0J+K14/JBH``ZKQNT#YK0$+
M"\$!$(I*`0^*2@$!JN']0M,A>`^J*P("BTH!#(NL_5O3+WQ`DDH!"XN,%0VJ
M:P`!JO&_0/F,`0H+`P(/BFL!#8IK`0.JH_U"TV-X#:J*_5O3:P$.BRX"`HM-
M%0RJ:P$.BRH``ZIN?$"2\<-`^:T!"POA`0Z*2@$,BDH!`:J!_4+3(7@,JJO]
M6]-*`1"+,`("BVP5#:I*`1"+:P`!JC!\0)+QQT#YC`$*"\,!$(IK`0V*:P$#
MJJ/]0M-C>`VJBOU;TVL!#XLO`@*+314,JFL!#XLJ``.J;WQ`DO'+0/FM`0L+
M`0(/BDH!#(I*`0&J@?U"TR%X#*JK_5O32@$.BRX"`HML%0VJ2@$.BVL``:HN
M?$"2\<]`^8P!"@OC`0Z*:P$-BFL!`ZJC_4+38W@-JHK]6]-K`1"+,`("BTT5
M#*IK`1"+*@`#JG!\0)+QTT#YK0$+"\$!$(I*`0R*2@$!JH']0M,A>`RJJ_U;
MTTH!#XLO`@*+;!4-JDH!#XMK``&J+WQ`DO'70/F,`0H+`P(/BFL!#8IK`0.J
MH_U"TV-X#:HJ`@*+:P$.BX[]6]-M?$"2:P$*B\X5#*HJ``.J\=M`^<X!"POA
M`0V*2@$,BDH!`:J!_4+3(7@,JLO]6]-*`1"+,`("BVP5#JI*`1"+:P`!JC!\
M0)+QWT#YC`$*"Z,!$(IK`0Z*:P$#JL/]0M-C>`ZJBOU;TVL!#XLO`@*+3A4,
MJFL!#XLJ``.J;WQ`DO'C0/D!`@^*2@$,BLX!"PM*`0&J@?U"TR%X#*HK`@*+
M2@$-BRQ\0))*`0N+:P`!JFL!#HKC`0R*:P$#JLW]6]-K`1"+K14.JO'#7*FM
M`0H+P_U"TV-X#JIN?$"2*@("B[']6],Q%@VJ:P$*BRH``ZHK`@L+@0$.BDH!
M#8I*`0&JH?U"TR%X#:H0`@*+2@$/BV_]6],M?$"22@$0B^\5"ZIC``&J\.]`
M^>\!"@MC``N*R@$-BF,`"JIJ_4+32GD+JF,`#(OQ_5O3#`("BS$6#ZHK``JJ
M8P`,BTQ]0)(A`@,+:P$/BJ,!#(IK`0.JX_U"TV-X#ZIK`0Z+\#]>J2[\6]/.
M%0&J2@$#JDH!`8KQ^T#Y$`("BVL!$(O+`0L+;GQ`DI`!#HI*`1"J</U;TTH!
M#8L0%@NJ[0$"BR("`HM*`0V++?Q"TZ%Y`:I003"+"GY`DB]\0))C``&JS0$/
MBF,`"XIR_4+38P`-JDW]6]-C``R+K14*JF(``HM+>@NJ34`MBR$`"\JQ?4"2
M(0`02N+_0/G#.IC2+/Y;TT-,N?(A``Z+0@`#BXP5$:HA``*+3OU"TRQ`+(O*
M>0JJD'U`DF(!"LKA`T'Y0@`-2@W^6]-"``^+(0`#BZT5$*I"``&++OY"TTU`
M+8O!>1&JKGU`DD\!`<KB!T'Y[P$,2LS]6]/K02N+0@`#BXP5#JIK`0*+#_Y"
MTVQ!+(OB>1"JCWU`DC```LKK"T'Y$`(-2NW]6],*0BJ+:P$#BZT5#ZI*`0N+
MT/U"TTU!+8L+>@ZJKGU`DE``"\KJ#T'Y$`(,2LS]6],!0B&+2@$#BXP5#JHA
M``J+\/U"TRQ`+(L*>@^JCWU`DG`!"LKA$T'Y$`(-2NW]6],"0B*+(0`#BZT5
M#ZI"``&+T/U"TTU`+8L!>@ZJKGU`DE`!`<KB%T'Y$`(,2LS]6],+0BN+0@`#
MBXP5#JIK`0*+\/U"TVQ!+(L">@^JCWU`DC```LKK&T'Y$`(-2NW]6],*0BJ+
M:P$#BZT5#ZI*`0N+T/U"TTU!+8L+>@ZJKGU`DE``"\KJ'T'Y$`(,2LS]6],!
M0B&+2@$#BXP5#JHA``J+\/U"TRQ`+(L*>@^JCWU`DG`!"LKA(T'Y$`(-2NW]
M6],"0B*+(0`#BZT5#ZI"``&+T/U"TTU`+8L!>@ZJKGU`DE`!`<KB)T'Y$`(,
M2LS]6],+0BN+0@`#BXP5#JIK`0*+\/U"TVQ!+(L">@^JCWU`DC```LKK*T'Y
M$`(-2NW]6],*0BJ+:P$#BZT5#ZI*`0N+T/U"TTU!+8L+>@ZJKGU`DE``"\KJ
M+T'Y$`(,2LS]6],!0B&+2@$#BXP5#JHA``J+\/U"TRQ`+(L*>@^JCWU`DG`!
M"LKA,T'Y$`(-2NW]6],"0B*+(0`#BZT5#ZI"``&+T/U"TTU`+8L!>@ZJKGU`
MDE`!`<KB-T'Y$`(,2LS]6],+0BN+C!4.JD(``XMK`0*+\/U"TVM!+(L">@^J
M;WU`DC```LKL.T'Y$`(-2NW]6],*0BJ+C`$#B]#]0M.M%0^J2@$,BPQZ#JI-
M02V+4``,RJY]0)(0`@M*ZS]!^<K]6],!0B&+2A4.JFL!`XOP_4+3(0`+BPMZ
M#ZHJ0"J+D`$+RD%]0)(0`@U*[T-!^2W\6],"0B*+K14!JN\!`XO0_4+30@`/
MBPYZ#JI-0"V+<`$.RN]'0?FB?4"2"@(*2C#\0M/O`0.+3$$LBTK\6],!>@&J
MC`$/BTH5`JKO2T'Y2@$,"\P!`<I0_$+3C0$-2NP!`XNK02N+0_U;TVL!#(MC
M%`JJ`GH"JF,`"PM&``8+90`%"\D!"0N$``H+(0`'"P40`*D&!`&IXT]!^0(!
M0/EB``+*"1``^8(``+7]>T"I_X,*D<`#7]8%]/^7_7N_J0`0@-+]`P"1Q?/_
MEQ\8`/DF8(32)7&5TL2?F]+#CHK2`CZ<TJ;HK/*E^;WR1!>S\D,&HO)">KCR
M!A0`J00,`:D"?`*I'W@`N?U[P:C``U_6'R`#U?U[O*E"?$"3_0,`D?-3`:D4
MX`"1\P,!JO5;`JGU`P"J]V,#J?<#`JH%C$*I`'A`N:0,`@N_``3K8Y2#FF)T
M0HNDB@*IX`(`-!8(@%+6`@!+_P(6:X#"((OVTI8:V'Y`D^(#&*I9\_^7H'I`
MN<`"``N@>@"Y'P`!<<```%3S4T&I]5M"J?=C0ZG]>\2HP`-?UO<"%DMS`AB+
MX`,5JH_[_Y?__@!Q[0,`5/<"`5'X?@93%F<:4]8"`9%V`A:+'R`#U6`&0*F`
M!@"I<P(!D6(.?:F"#@&IX`,5JF06?JF$%@*I9!9_J806`ZE\^_^7?P(6ZX'^
M_U3W&AA+X0,6JN)^0)/@`Q2J,?/_E[=Z`+GS4T&I]5M"J?=C0ZG]>\2HP`-?
MUO8#$ZKU__\7_7N\J?T#`)'S4P&I\P,!JO0#`*KU6P*I=>(`D>$/@!+W&P#Y
M8!9`^78J0+EW,D"Y`"`#4]8*P%H"!``1]PK`6E_@`'&ARB`XH,(BBXT)`%0!
M"(!2(@`"2P$`@%)"?$"3://_E^`#$ZI2^_^7?_X#J7_^!*E__@6I?S8`^7=:
M#BG@`Q.J2_O_EV$"0/G@`Q.J(?Q8TX$"`#EA`D#Y(?Q0TX$&`#EA`D#Y(?Q(
MTX$*`#EA`D#Y@0X`.6$&0/DA_%C3@1(`.6$&0/DA_%#3@18`.6$&0/DA_$C3
M@1H`.6$&0/F!'@`Y80I`^2'\6-.!(@`Y80I`^2'\4-.!)@`Y80I`^2'\2-.!
M*@`Y80I`^8$N`#EA#D#Y(?Q8TX$R`#EA#D#Y(?Q0TX$V`#EA#D#Y(?Q(TX$Z
M`#EA#D#Y@3X`.6$20/DA_%C3@4(`.6$20/DA_%#3@48`.6$20/DA_$C3@4H`
M.6$20/F!3@`Y\U-!J?5;0JGW&T#Y_7O$J(;S_Q<!!X!2(@`"2P$`@%)"?$"3
M'?/_E[O__Q<?(`/5`P``D&/,0/GP\O\7'R`#U?U[O*G]`P"1\U,!J;0``)"4
M(C>1]5L"J;4``)"U`C>1E`(5R_8#`"KW8P.I]P,!JO@#`JJ4_D.3H/+_EW0!
M`+03`(#2'R`#U:-Z<_CB`QBJ<P8`D>$#%ZK@`Q8J8``_UI\"$^LA__]4\U-!
MJ?5;0JGW8T.I_7O$J,`#7]8?(`/5P`-?UOU[OZG]`P"1_7O!J,`#7]8`````
M`0`"``````````````````````````````````````!P97)L>'-I+F,`````
M````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("```````````!!6
M0```````2%)``````````````````*A30```````\%5```````#X54``````
M``!60```````"%9``````````````````-A50```````X%5`````````````
M`````"X`````````+BX````````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$
M>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2
M.CI"3T]4`````&5X90``````+W!R;V,O)6DO)7,``````%!!4E]414U0````
M``````!005)?4%)/1TY!344`````.@`````````O`````````"5S)7,E<P``
M4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)
M3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`
M````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?1TQ/
M0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?
M5$U01$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`
M`````````%!!4E]#3$5!3CT````````Q`````````$Q$7TQ)0E)!4EE?4$%4
M2`!365-414T``"4P,G@`````<&%R+0`````E<R5S)7,E<P``````````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H```````!0051(`````'!A<FP`````+G!A<@`````E<R5S8V%C
M:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````
M`````$%21U8`````&`````````!P97)L`````#``````````4$%2.CI086-K
M97(Z.E9%4E-)3TX`````,2XP-#@```!5;F%B;&4@=&\@8W)E871E(&-A8VAE
M(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C
M:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````
M+64````````M+0```````%5315(`````55-%4DY!344``````````%1-4$1)
M4@``5$5-4$1)4@!414U0`````%1-4```````+W1M<`````!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE
M("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]
M("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E
M("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE
M;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?
M:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@
M)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^
M("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?
M<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@
M)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(
M*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S
M970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]
M("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T
M+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=
M.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q
M6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A
M9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN
M(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@
M)&]F9G-E="`^(#(U-B`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N
M;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(
M+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M
M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U
M9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E
M7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D
M9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L
M;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M
M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E
M>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E
M>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L
M;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@
M;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM
M>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F
M+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92![
M"B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C
M<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I
M;F9O(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@;W(@<F5T=7)N
M.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1I;F9O+3Y[8G5F?3L*<V5E:R@D
M9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@
M/2!?=&5M<&9I;&4H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D[
M"F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E
M860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*
M?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D
M=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T
M(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE
M;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA
M;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E
M('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T
M;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA
M;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A
M<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H
M)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D
M14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@
M82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!
M4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*
M<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL
M7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6
M(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`
M05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE
M;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@
M)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@
M>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I
M970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE
M;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H
M0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E
M("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$
M:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N
M<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z
M:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I
M92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R
M;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE
M("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A
M(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN
M;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?
M<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A
M;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N
M=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A
M;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y6
M7U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@
M=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U[
M"B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H
M)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E
M9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?
M;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@
M>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV
M;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R
M($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,[
M"FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E
M=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA
M;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M
M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\[
M"FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM
M(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]
M("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M
M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E
M;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@
M+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@
M(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN
M+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT
M(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I
M;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,
M12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@
M87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R
M:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D
M8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II
M<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA
M;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X
M(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)&]U
M="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D
M9F@I.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?
M;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A
M8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4[
M"F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I
M;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005([
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I
M;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"D%R8VAI=F4Z.EII
M<#HZ<V5T0VAU;FM3:7IE*#(U-BHQ,#(T*3L*;7D@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E
M;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE
M;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D[
M"GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE
M*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER
M92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR
M97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S
M.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF
M:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE
M=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z
M.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T
M('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T[
M"F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA
M<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E
M;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*
M9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U0
M1$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@
M+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD
M("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60[
M"F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W
M=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H
M)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D[
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H
M;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y
M<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD
M8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@)&)U9CL*?0IE;'-E('L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@)&9H+"`B
M/"(L("1P<F]G;F%M92D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D
M9F@I.PIC;&]S92@D9F@I.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M(B`N("1C='@M/FAE>&1I9V5S=#L*?0IC;&]S92@D9F@I.PI]"F5L
M<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@
M)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L
M("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE
M(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F
M=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D
M:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*
M<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@
M)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L
M("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F
M=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%
M3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H
M+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII
M9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM0
M05)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]
M"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG
M>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O
M9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92![
M"B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G
M;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D
M(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H
M*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@
M8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_
M7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET
M7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*
M<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]
M"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O
M(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]]
M(#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%2
M7T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.
M5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A
M<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!
M3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*
M<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R
M:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]
M"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*
M0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?
M7T5.1%]?"@`!&P,[#`$``"````"(D/__<`8``/B2__\D`0``*)/__S@!``!@
MD___3`$``)"3__]P`0``F)/__X@!``"(E/__\`$``"B5__\<`@``4)?__VP"
M``#0F/__X`(``&"9__\(`P``B)K__T0#``#`FO__9`,``!";__^(`P``X)O_
M_[P#``#HF___T`,``."=__\H!```$)[__SP$```PG___<`0``/B@__^D!```
M@*'__\P$``"@H?__[`0``)"B__\D!0``(*G__\`%```(K?__0`8``(BM__^@
M!@``6+[__\0&``"POO__Y`8``-B___\H!P``<,'__V`'``"`P?__>`<```#"
M__^L!P```````!```````````7I2``1X'@$;#!\`$````!@```#,D?__+```
M```````0````+````.B1__\X`````````"````!`````#)+__S``````00X@
MG02>`T*3`DC>W=,.`````!0```!D````&)+__P0``````````````&0```!\
M````")+__^P`````00Y`G0B>!T*3!I0%0Y@!EP)#E@.5!%;6U4'8UT/>W=/4
M#@!!#D"3!I0%E026`Y<"F`&=")X'3];50=C70=[=T]0.`$$.0),&E`6=")X'
M0I<"F`%"V-<`*````.0```"0DO__G`````!!#D"=")X'0I4$0Y,&E`5?"M[=
MU=/4#@!!"P!,````$`$```23__\D`@```$$.<)T.G@U"DPR4"TN5"I8)EPB8
M!YD&F@4"0`K>W=G:U]C5UM/4#@!!"TB;!%X*VT$+2=M"FP1$VT.;!````'``
M``!@`0``W)3__WP!````00[@`9T<GAM"DQJ4&4>8%9<61-C71M[=T]0.`$$.
MX`&3&I09EQ:8%9T<GAM!EA>5&%69%&#92`K6U4'8UT$+0=;50=C70948EA>7
M%I@5F11#U=;7V-E!EA>5&$&8%9<609D4)````-0!``#HE?__C`````!!#K`!
MG1:>%4.3%)0350K>W=/4#@!!"S@```#\`0``4);__R0!````0@[0($*=B@2>
MB01"DX@$E(<$0Y6&!):%!$>7A`1B"MW>U]76T]0.`$$+`!P````X`@``/)?_
M_S0`````00X0G0*>`47>W0X`````(````%@"``!4E___4`````!!#B"=!)X#
M0I,"2=[=TPX`````,````'P"``"`E___T`````!"#M!`09V*")Z)"$*3B`B4
MAPA&E88(9PK=WM73U`X`00L``!````"P`@``')C__P0`````````5````,0"
M```0F/__]`$```!"#N`A09V<!)Z;!$*7E@28E01#F90$FI,$1Y.:!)29!%<*
MW=[9VM?8T]0.`$$+0I:7!)68!'T*UM5!"U/6U4*6EP25F`0``!`````<`P``
ML)G__RP`````````,````#`#``#,F?__'`$```!"#B"=!)X#0I,"6`K>W=,.
M`$(+8`K>W=,.`$$+0][=TPX``#````!D`P``N)K__\@!````0PZ``9T0G@]$
MDPZ4#4R5#)8+0I<*`D@*WMW7U=;3U`X`00LD````F`,``$R<__^$`````$$.
M,)T&G@5"DP24`T\*WMW3U`X`00L`'````,`#``"LG/__(`````!!#A"=`IX!
M1M[=#@`````T````X`,``*R<___L`````$$.4)T*G@E"DPB4!T65!I8%50K>
MW=76T]0.`$$+19<$5=="EP0``)@````8!```9)W__XP&````0@ZP@P)#G;0@
MGK,@1Y.R()2Q()6P():O($67KB"8K2!7FJL@F:P@09NJ(`)9VME!VTS=WM?8
MU=;3U`X`00ZP@P*3LB"4L2"5L""6KR"7KB"8K2"9K"":JR";JB"=M"">LR`"
M>0K:V4';00MAVME!VT:9K"":JR";JB`";=G:VT&:JR"9K"!!FZH@`'P```"T
M!```6*/__^0#````00Z``9T0G@]"EPJ8"4.9")H'1Y,.E`V5#)8+6@5(!$R<
M!9L&:MS;009(`E$*WMW9VM?8U=;3U`X`00M.FP:<!05(!%#<VT$&2$F<!9L&
M005(!$?;W`9(3@J<!9L&005(!$$+0IP%FP9"!4@$````+````#0%``#`IO__
M@`````!!#B"=!)X#0I,"E`%0"M[=T]0.`$$+2][=T]0.````+````&0%```0
MBO__"`(```!!#F"=#)X+0I,*E`E&E0@"6@K>W=73U`X`00L`````(````)0%
M``#@IO__T!````!!#J`%1YU4GE,#*@0*W=X.`$$+'````+@%``",M___5```
M``!!#A"=`IX!4][=#@````!`````V`4``,2W__\H`0```$$.0)T(G@=#DP:4
M!4.5!)8#0I<"F`%:"M[=U]C5UM/4#@!!"V,*WMW7V-76T]0.`$$+`#0````<
M!@``J+C__Y0!````00Y`G0B>!T*3!I0%0Y4$E@-#EP("50K>W=?5UM/4#@!!
M"P``````%````%0&```(NO__#```````````````,````&P&````NO__?```
M``!!#D"=")X'0I,&E`5#E026`T67`I@!4][=U]C5UM/4#@```!````"@!@``
M3+K__P0`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````@C0```````V")```````````````````$`
M`````````0`````````!`````````+P!`````````0`````````+`@``````
M``$`````````2`,````````,`````````+`;0```````#0````````!\44``
M`````!D`````````P)U!```````;``````````@`````````&@````````#(
MG4$``````!P`````````"`````````#U_O]O`````*`"0```````!0``````
M``#H#D````````8`````````R`1````````*`````````.4$````````"P``
M```````8`````````!4````````````````````#`````````.B?00``````
M`@`````````8!@```````!0`````````!P`````````7`````````)@50```
M````!P`````````(%4````````@`````````D``````````)`````````!@`
M````````_O__;P````"H%$```````/___V\``````P````````#P__]O````
M`,X30```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````V)U!````````````````````````````````````
M`````````````-`;0```````T!M```````#0&T```````-`;0```````T!M`
M``````#0&T```````-`;0```````T!M```````#0&T```````-`;0```````
MT!M```````#0&T```````-`;0```````T!M```````#0&T```````-`;0```
M````T!M```````#0&T```````-`;0```````T!M```````#0&T```````-`;
M0```````T!M```````#0&T```````-`;0```````T!M```````#0&T``````
M`-`;0```````T!M```````#0&T```````-`;0```````T!M```````#0&T``
M`````-`;0```````T!M```````#0&T```````-`;0```````T!M```````#0
M&T```````-`;0```````T!M```````#0&T```````-`;0```````T!M`````
M``#0&T```````-`;0```````T!M```````#0&T```````-`;0```````T!M`
M``````#0&T```````-`;0```````T!M```````#0&T```````-`;0```````
MT!M```````#0&T```````-`;0```````T!M```````#0&T```````-`;0```
M````T!M```````#0&T```````-`;0```````T!M``````````````````/__
M__\`````&%9```````!'0T,Z("A'3E4I(#@N,BXQ(#(P,3@Q,C$U("A!3%0@
M4VES>7!H=7,@."XR+C$M86QT,BD`1T-#.B`H1TY5*2`X+C,N,2`R,#$Y,#,Q
M,2`H04Q4(%-I<WEP:'5S(#@N,RXQ+6%L=#,I`"U)("XN+VEN8VQU9&4`+4D@
M+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N,C<M86QT."]B=6EL9"UA87)C
M:#8T+6QI;G5X+V-S=0`M22`O=7-R+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXR
M-RUA;'0X+V)U:6QD+6%A<F-H-C0M;&EN=7@`+4D@+BXO<WES9&5P<R]U;FEX
M+W-Y<W8O;&EN=7@O86%R8V@V-``M22`N+B]S>7-D97!S+V%A<F-H-C0O;G!T
M;``M22`N+B]S>7-D97!S+W5N:7@O<WES=B]L:6YU>"]G96YE<FEC`"U)("XN
M+W-Y<V1E<',O=6YI>"]S>7-V+VQI;G5X+W=O<F1S:7IE+38T`"U)("XN+W-Y
M<V1E<',O=6YI>"]S>7-V+VQI;G5X+VEN8VQU9&4`+4D@+BXO<WES9&5P<R]U
M;FEX+W-Y<W8O;&EN=7@`+4D@+BXO<WES9&5P<R]N<'1L`"U)("XN+W-Y<V1E
M<',O<'1H<F5A9``M22`N+B]S>7-D97!S+V=N=0`M22`N+B]S>7-D97!S+W5N
M:7@O:6YE=``M22`N+B]S>7-D97!S+W5N:7@O<WES=@`M22`N+B]S>7-D97!S
M+W5N:7@`+4D@+BXO<WES9&5P<R]P;W-I>``M22`N+B]S>7-D97!S+V%A<F-H
M-C0O9G!U`"U)("XN+W-Y<V1E<',O86%R8V@V-"]M=6QT:6%R8V@`+4D@+BXO
M<WES9&5P<R]A87)C:#8T`"U)("XN+W-Y<V1E<',O=V]R9'-I>F4M-C0`+4D@
M+BXO<WES9&5P<R]I965E-S4T+VQD8FPM,3(X`"U)("XN+W-Y<V1E<',O:65E
M93<U-"]D8FPM-C0O=V]R9'-I>F4M-C0`+4D@+BXO<WES9&5P<R]I965E-S4T
M+V1B;"TV-``M22`N+B]S>7-D97!S+VEE964W-30O9FQT+3,R`"U)("XN+W-Y
M<V1E<',O86%R8V@V-"]S;V9T+69P`"U)("XN+W-Y<V1E<',O:65E93<U-``M
M22`N+B]S>7-D97!S+V=E;F5R:6,`+4D@+BX`+4D@+BXO;&EB:6\`+4D@+@`M
M340@+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N,C<M86QT."]B=6EL9"UA
M87)C:#8T+6QI;G5X+V-S=2]I;FET+F0`+4U&("]U<W(O<W)C+U)032]"54E,
M1"]G;&EB8RTR+C(W+6%L=#@O8G5I;&0M86%R8V@V-"UL:6YU>"]C<W4O:6YI
M="YO+F1T`"U-4``M350@+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N,C<M
M86QT."]B=6EL9"UA87)C:#8T+6QI;G5X+V-S=2]I;FET+F\`+40@4U1!0TM?
M4%)/5$5#5$]27TQ%5D5,/3``+54@7T9/4E1)1EE?4T]54D-%`"U$(%],24)#
M7U)%14Y44D%.5``M1"!-3T153$5?3D%-13UL:6)C`"U$(%1/4%].04U%4U!!
M0T4]9VQI8F,`+6EN8VQU9&4@+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N
M,C<M86QT."]B=6EL9"UA87)C:#8T+6QI;G5X+VQI8F,M;6]D=6QE<RYH`"UI
M;F-L=61E("XN+VEN8VQU9&4O;&EB8RUS>6UB;VQS+F@`+6UL:71T;&4M96YD
M:6%N`"UM86)I/6QP-C0`+6%U>&)A<V4M<W1R:7`@+W5S<B]S<F,O4E!-+T)5
M24Q$+V=L:6)C+3(N,C<M86QT."]B=6EL9"UA87)C:#8T+6QI;G5X+V-S=2]I
M;FET+F\`+6<`+4\R`"U786QL`"U797)R;W(`+5=U;F1E9@`M5W=R:71E+7-T
M<FEN9W,`+5=S=')I8W0M<')O=&]T>7!E<P`M5V]L9"US='EL92UD969I;FET
M:6]N`"US=&0]9VYU,3$`+69G;G4X.2UI;FQI;F4`+69M97)G92UA;&PM8V]N
M<W1A;G1S`"UF<F5C;W)D+6=C8RUS=VET8VAE<P`M9G)O=6YD:6YG+6UA=&@`
M+69S=&%C:RUP<F]T96-T;W(M<W1R;VYG`"UF;F\M<W1A8VLM<')O=&5C=&]R
M`"UF=&QS+6UO9&5L/6EN:71I86PM97AE8P`M340@+W5S<B]S<F,O4E!-+T)5
M24Q$+V=L:6)C+3(N,C<M86QT."]B=6EL9"UA87)C:#8T+6QI;G5X+V-S=2]S
M=&%T:6,M<F5L;V,N9``M348@+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N
M,C<M86QT."]B=6EL9"UA87)C:#8T+6QI;G5X+V-S=2]S=&%T:6,M<F5L;V,N
M;RYD=``M350@+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N,C<M86QT."]B
M=6EL9"UA87)C:#8T+6QI;G5X+V-S=2]S=&%T:6,M<F5L;V,N;P!S=&%T:6,M
M<F5L;V,N8P`M875X8F%S92US=')I<"`O=7-R+W-R8R]24$TO0E5)3$0O9VQI
M8F,M,BXR-RUA;'0X+V)U:6QD+6%A<F-H-C0M;&EN=7@O8W-U+W-T871I8RUR
M96QO8RYO`"U)("]U<W(O;&]C86PO:6YC;'5D90`M22`O=7-R+VQI8C8T+W!E
M<FPU+T-/4D4`+40@7U)%14Y44D%.5``M1"!?1TY57U-/55)#10`M1"!?3$%2
M1T5&24Q%7U-/55)#10`M1"!?1DE,15]/1D93151?0DE44STV-``M1"!,1$Q)
M0E!42$Y!344](DQ$7TQ)0E)!4EE?4$%42"(`+40@4$%23%]%6$4](G!A<FPB
M`"U$(%!!4E]004-+15)?5D524TE/3CTB,2XP-#@B`&UA:6XN8P`M9G=R87!V
M`"UF;F\M<W1R:6-T+6%L:6%S:6YG`"U$($)95$5/4D1%4CTP>#$R,S0U-C<X
M`"U$(%4V-%194$4]=6YS:6=N960@;&]N9P!S:&$Q+F,`+4D@+W5S<B]S<F,O
M4E!-+T)524Q$+V=L:6)C+3(N,C<M86QT."]B=6EL9"UA87)C:#8T+6QI;G5X
M+VYP=&P`+4U$("]U<W(O<W)C+U)032]"54E,1"]G;&EB8RTR+C(W+6%L=#@O
M8G5I;&0M86%R8V@V-"UL:6YU>"]N<'1L+W!T:')E861?871F;W)K+F0`+4U&
M("]U<W(O<W)C+U)032]"54E,1"]G;&EB8RTR+C(W+6%L=#@O8G5I;&0M86%R
M8V@V-"UL:6YU>"]N<'1L+W!T:')E861?871F;W)K+F]3+F1T`"U-5"`O=7-R
M+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXR-RUA;'0X+V)U:6QD+6%A<F-H-C0M
M;&EN=7@O;G!T;"]P=&AR96%D7V%T9F]R:RYO4P`M1"!-3T153$5?3D%-13UL
M:6)P=&AR96%D`"U$(%!)0P`M1"!,24)#7TY/3E-(05)%1#TQ`'!T:')E861?
M871F;W)K+F,`+6%U>&)A<V4M<W1R:7`@+W5S<B]S<F,O4E!-+T)524Q$+V=L
M:6)C+3(N,C<M86QT."]B=6EL9"UA87)C:#8T+6QI;G5X+VYP=&PO<'1H<F5A
M9%]A=&9O<FLN;U,`+69024,`+4U$("]U<W(O<W)C+U)032]"54E,1"]G;&EB
M8RTR+C(W+6%L=#@O8G5I;&0M86%R8V@V-"UL:6YU>"]C<W4O96QF+6EN:70N
M9``M348@+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N,C<M86QT."]B=6EL
M9"UA87)C:#8T+6QI;G5X+V-S=2]E;&8M:6YI="YO4RYD=``M350@+W5S<B]S
M<F,O4E!-+T)524Q$+V=L:6)C+3(N,C<M86QT."]B=6EL9"UA87)C:#8T+6QI
M;G5X+V-S=2]E;&8M:6YI="YO4P!E;&8M:6YI="YC`"UA=7AB87-E+7-T<FEP
M("]U<W(O<W)C+U)032]"54E,1"]G;&EB8RTR+C(W+6%L=#@O8G5I;&0M86%R
M8V@V-"UL:6YU>"]C<W4O96QF+6EN:70N;U,``"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N
M96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A
M>0`N9&%T82YR96PN<F\`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N
M8G-S`"YC;VUM96YT`"Y'0T,N8V]M;6%N9"YL:6YE````````````````````
M````````````````````````````````````````````````````````````
M```````````+`````0````(`````````.`)````````X`@```````!T`````
M```````````````!````````````````````$P````<````"`````````%@"
M0```````6`(````````@````````````````````!```````````````````
M`"$````'`````@````````!X`D```````'@"````````)```````````````
M``````0````````````````````T````]O__;P(`````````H`)```````"@
M`@```````"0"````````!0`````````(````````````````````/@````L`
M```"`````````,@$0```````R`0````````@"@````````8````!````"```
M```````8`````````$8````#`````@````````#H#D```````.@.````````
MY00```````````````````$```````````````````!.````____;P(`````
M````SA-```````#.$P```````-@`````````!0`````````"``````````(`
M````````6P```/[__V\"`````````*@40```````J!0```````!@````````
M``8````#````"````````````````````&H````$`````@`````````(%4``
M``````@5````````D``````````%``````````@`````````&`````````!T
M````!````$(`````````F!5```````"8%0```````!@&````````!0```!<`
M```(`````````!@`````````?@````$````&`````````+`;0```````L!L`
M```````4````````````````````!````````````````````'D````!````
M!@````````#0&T```````-`;````````,`0``````````````````!``````
M````$`````````"$`````0````8``````````"!`````````(````````'PQ
M```````````````````(````````````````````B@````$````&````````
M`'Q10```````?%$````````0````````````````````!```````````````
M`````)`````!`````@````````"044```````)!1````````Z#T`````````
M``````````@```````````````````"8`````0````(`````````>(]`````
M``!XCP````````P!```````````````````$````````````````````I@``
M``$````"`````````(B00```````B)````````"T!@``````````````````
M"````````````````````+`````.`````P````````#`G4$``````,"=````
M````"`````````````````````@`````````"`````````"\````#P````,`
M````````R)U!``````#(G0````````@````````````````````(````````
M``@`````````R`````$````#`````````-"=00``````T)T````````(````
M````````````````"````````````````````-4````&`````P````````#8
MG4$``````-B=``````````(````````&``````````@`````````$```````
M``#>`````0````,`````````V)]!``````#8GP```````!``````````````
M```````(``````````@`````````XP````$````#`````````.B?00``````
MZ)\````````@`@``````````````````"``````````(`````````.P````!
M`````P`````````(HD$```````BB````````&`````````````````````@`
M``````````````````#R````"`````,`````````(*)!```````@H@``````
M`$@0```````````````````(````````````````````]P````$````P````
M````````````````(*(```````!H`````````````````````0`````````!
M```````````!```!````,````````````````````(BB````````\PL`````
M``````````````$``````````0`````````!`````P``````````````````
M``````![K@```````!(!```````````````````!````````````````````
